==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder extends EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluentImpl<EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder> implements VisitableBuilder<EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration,EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder>{
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder() {
    this(false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withRouteConfiguration(instance.getRouteConfiguration());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration instance) {
    this(instance,false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withRouteConfiguration(instance.getRouteConfiguration());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration build() {
    EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration buildable = new EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration(fluent.getRouteConfiguration());
    return buildable;
  }
  
}

==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder extends EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder> implements VisitableBuilder<EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration,EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder>{
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder() {
    this(false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(Boolean validationEnabled) {
    this(new EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<?> fluent) {
    this(fluent, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration(), validationEnabled);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration instance) {
    this(fluent, instance, false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<?> fluent,EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration());

    if (instance != null) {
      fluent.withRouteConfiguration(instance.getRouteConfiguration());
      fluent.withRouteConfiguration(instance.getRouteConfiguration());
    }
    this.validationEnabled = validationEnabled; 
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration instance) {
    this(instance,false);
  }
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationBuilder(EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration());

    if (instance != null) {
      this.withRouteConfiguration(instance.getRouteConfiguration());
      this.withRouteConfiguration(instance.getRouteConfiguration());
    }
    this.validationEnabled = validationEnabled; 
  }
  EnvoyFilterEnvoyConfigObjectMatchRouteConfigurationFluent<?> fluent;
  Boolean validationEnabled;
  public EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration build() {
    EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration buildable = new EnvoyFilterEnvoyConfigObjectMatchRouteConfiguration(fluent.buildRouteConfiguration());
    return buildable;
  }
  
}
